@@ -32,7 +32,7 @@ def is_cpr_number(cpr_number: str) -> bool:
     format of a Danish CPR-number: DDMMYY(-)NNNN.
     '''
 
-    if 10 <= len(cpr_number) <= 11:
+    if not (10 <= len(cpr_number) <= 11):
         return False
 
     cpr_number = cpr_number.replace('-', '')
